/*============================================================================
  File:     VerifyTableDifferences.sql

  Summary:  This script verifies the differences between the original SalesDB
			and the modified SalesDB restored as SalesDB_Diffs.
  
  Date:     June 2010

  SQL Server Version: SQL Server 2008 SP1
------------------------------------------------------------------------------
  Written by Kimberly L. Tripp & Paul S. Randal, SQLskills.com

  For more scripts and sample code, check out 
    http://www.SQLskills.com

  This script is intended only as a supplement to demos and lectures
  written/presented by SQLskills.com  
  
  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

-- If the commands were database commands, you could use the undocumented sp_msforeachtable command
-- The following line can help you to quickly find row count differences - but this doesn't account for
-- rows that have been deleted and new rows have been added.
-- sp_MSforeachtable @command1="select count(*) AS 'SalesDB_Diffs.?' from ?; select count(*) AS 'SalesDB.?' from SalesDB.?"  


------------------------------------------------------------------------------
-- Create a temp table to store the commands
------------------------------------------------------------------------------

USE SalesDB
go
DROP TABLE ExecuteDifferences
go

CREATE TABLE ExecuteDifferences
(
	DiffID		int				identity,
	DiffExec	nvarchar(4000)
)
go

------------------------------------------------------------------------------
-- Create SQLCMD variables to help simplify the command build
------------------------------------------------------------------------------
:SETVAR SourceServer (local)\SQLDEV01
:SETVAR SourceDatabase SalesDB_Diffs

:SETVAR DestinationServer (local)\SQLDEV01
:SETVAR DestinationDatabase SalesDB_Snapshot

DECLARE @CurrentName sysname, @ExecStr nvarchar(4000)
SELECT @CurrentName = (SELECT min(name) FROM sys.tables WHERE name NOT IN ('sysdiagrams', 'ExecuteDifferences'))

WHILE @CurrentName <= (SELECT max(name) FROM sys.tables WHERE name NOT IN ('sysdiagrams', 'ExecuteDifferences')) 
BEGIN
	SELECT @ExecStr = 'INSERT ExecuteDifferences (DiffExec) VALUES (''!!"c:\program files\microsoft sql server\100\com\tablediff.exe" -sourceserver $(SourceServer) -sourcedatabase $(SourceDatabase) -sourcetable ' + @CurrentName + ' -destinationserver $(DestinationServer) -destinationdatabase $(DestinationDatabase) -destinationtable ' + @CurrentName + ' -c -dt ' + @CurrentName + '_Diffs -f C:\SQLskills\' + @CurrentName + '_Diffs.sql'')'
	--SELECT @ExecStr
	EXEC (@ExecStr)
	SELECT @CurrentName = (SELECT min(name) FROM sys.tables WHERE name NOT IN ('sysdiagrams', 'ExecuteDifferences') AND name > @CurrentName)
END
go

SELECT * FROM ExecuteDifferences
go